import requests
from urllib.parse import urlencode, quote_plus

def translate(text,source_lang,target_lang):
    payload = {'target':target_lang, 'source':source_lang,'text':text}
    result = urlencode(payload, quote_via=quote_plus)
    response = requests.get(f"http://api.mlaas.me/translator/translate?{result}")
    return response.json()['translation'][0]


if __name__=='__main__':
    translate("this is a sentece",'en','fr')


import requests
from urllib.parse import urlencode, quote_plus
import os
import base64
import json   

def speech2text(audio_path):
    url = "https://api.mlaas.me/speech_to_text/speech_to_text"
    data = open(audio_path, 'rb').read()
    data_b64 = base64.b64encode(data).decode("utf8")
    content = {'audio_path':audio_path,'audio_data':data_b64 }

    text = requests.post(url, data = content).json()['text']
    return text



if __name__=='__main__':
    speech2text("/home/mlaas/repos/python-client/tmp/text2speech/out.wav")


import requests
from urllib.parse import urlencode, quote_plus
import os

def text2speech(text,output_path='tmp/text2speech/out.wav'):
    payload = {'text':text}
    encoded = urlencode(payload, quote_via=quote_plus)
    response = requests.get(f"https://api.mlaas.me/text_to_speech/text_to_speech?{encoded}",timeout=5)
    storage_path = response.json()['storage_path']
    content = requests.get(storage_path, allow_redirects=True).content

    os.makedirs(os.path.dirname(output_path),exist_ok=True)
    open(output_path, 'wb').write(content)
    return output_path



if __name__=='__main__':
    text2speech("this is a sentece")


import requests
from urllib.parse import urlencode, quote_plus
import os
import base64
import json   

def background_removal(img_path,output_path):
    url = "https://api.mlaas.me/background_removal/background_removal"
    # url = "http://127.0.0.1:5001/background_removal/background_removal"
    data = open(img_path, 'rb').read()
    data_b64 = base64.b64encode(data).decode("utf8")
    is_video = img_path[-3:] not in ['png','jpg']
    content = {'img_path':img_path,'img_data':data_b64,'is_video':str(is_video).lower() }

    background_free_img = requests.post(url, data = content).json()['data']
    content_bytes = base64.b64decode(background_free_img.encode('utf-8'))
    os.makedirs(os.path.dirname(output_path),exist_ok=True)
    open(output_path, 'wb').write(content_bytes)
    return 


if __name__=='__main__':
    background_removal("/home/mlaas/repos/python-client/tmp/image_background_removal/20210603073725_Trim_Trim.mp4",output_path='tmp/background_removal/out.mp4')


from setuptools import setup, find_packages

VERSION = '0.0.10' 
DESCRIPTION = 'ML as a service toolkit'
LONG_DESCRIPTION = 'ML as a service toolkit'

install_requires = [
    'requests',
]
# Setting up
setup(
        name="mlaas", 
        version=VERSION,
        author="dvirginz@gmail.com",
        author_email="<dvirginz@gmail.com>",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        keywords=['python', 'ML'],
        install_requires=install_requires,
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Programming Language :: Python :: 3",
        ]
)


from .translation import translate
from .text2speech import text2speech
from .speech2text import speech2text
from .image_background_removal import background_removal


__all__ = [
    'translate',
    'text2speech',
    'speech2text',
    'background_removal',
]